@@ -909,8 +909,8 @@ meta_data_addr6(void)
 	"  <actions>\n"
 	"    <action name=\"start\"   timeout=\"15\" />\n"
 	"    <action name=\"stop\"    timeout=\"15\" />\n"
-	"    <action name=\"status\"  timeout=\"15\" interval=\"15\" start-delay=\"0\" />\n"
-	"    <action name=\"monitor\" timeout=\"15\" interval=\"15\" start-delay=\"0\" />\n"
+	"    <action name=\"status\"  timeout=\"15\" interval=\"15\" />\n"
+	"    <action name=\"monitor\" timeout=\"15\" interval=\"15\" />\n"
 	"    <action name=\"validate-all\"  timeout=\"5\" />\n"
 	"    <action name=\"meta-data\"  timeout=\"5\" />\n"
 	"  </actions>\n"
